==> haskell-tamarin-prover-utils-1.4.0-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tamarin-prover-utils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tamarin-prover-utils
version: 1.4.0
id: tamarin-prover-utils-1.4.0-FPAYC29IdTs8fYvlf6lR1h
key: tamarin-prover-utils-1.4.0-FPAYC29IdTs8fYvlf6lR1h
license: LicenseRef-GPL
copyright: Benedikt Schmidt, Simon Meier, Jannik Dreier, Ralf Sasse, ETH Zurich, 2010-2018
maintainer: Simon Meier <simon.meier@inf.ethz.ch>,
            Jannik Dreier <research@jannikdreier.net>,
            Ralf Sasse <ralf.sasse@gmail.com>
author: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
        Simon Meier <simon.meier@inf.ethz.ch>,
        Jannik Dreier <research@jannikdreier.net>,
        Ralf Sasse <ralf.sasse@gmail.com>
homepage: https://tamarin-prover.github.io/
synopsis: Utility library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
category: Theorem Provers
abi: 60b527efdb7c65854ac1fed4d201f234
exposed: True
exposed-modules:
    Control.Basics Control.Monad.Bind Control.Monad.Disj
    Control.Monad.Fresh Control.Monad.Trans.FastFresh
    Control.Monad.Trans.PreciseFresh Data.Color Data.DAG.Simple
    Debug.Trace.Ignore Extension.Data.Bounded Extension.Data.ByteString
    Extension.Data.Label Extension.Data.Monoid Extension.Prelude
    Logic.Connectives System.Timing Text.Dot Text.PrettyPrint.Class
    Text.PrettyPrint.Highlight Text.PrettyPrint.Html Text.Unicode
    Utils.Misc
hidden-modules: Control.Monad.Fresh.Class Control.Monad.Trans.Disj
                Control.Monad.Disj.Class
import-dirs: /usr/lib/ghc-8.6.2/site-local/tamarin-prover-utils-1.4.0
library-dirs: /usr/lib/ghc-8.6.2/site-local/tamarin-prover-utils-1.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/tamarin-prover-utils-1.4.0
hs-libraries: HStamarin-prover-utils-1.4.0-FPAYC29IdTs8fYvlf6lR1h
depends:
    SHA-1.6.4.4-1GMMHy6WdrlGpMrtGTWHUv base-4.12.0.0
    base64-bytestring-1.0.0.1-G3Br32Wzx6yIe8CvhfIHtS binary-0.8.6.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    containers-0.6.0.1 deepseq-1.4.4.0
    dlist-0.8.0.5-HU8Aimky3DbFEV0DkwGifS
    fclabels-2.0.3.3-BnphqeNcghO5EF7ELGWEgj mtl-2.2.2 pretty-1.1.3.6
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji syb-0.7-KRW1LCxdMiCJrmhxCvzo37
    time-1.8.0.2 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-tamarin-prover-utils/html/tamarin-prover-utils.haddock
haddock-html: /usr/share/doc/haskell-tamarin-prover-utils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-utils-1.4.0-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tamarin-prover-utils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tamarin-prover-utils
version: 1.4.0
id: tamarin-prover-utils-1.4.0-7FcHB8rkcz5IDYEgw7ddaE
key: tamarin-prover-utils-1.4.0-7FcHB8rkcz5IDYEgw7ddaE
license: LicenseRef-GPL
copyright: Benedikt Schmidt, Simon Meier, Jannik Dreier, Ralf Sasse, ETH Zurich, 2010-2018
maintainer: Simon Meier <simon.meier@inf.ethz.ch>,
            Jannik Dreier <research@jannikdreier.net>,
            Ralf Sasse <ralf.sasse@gmail.com>
author: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
        Simon Meier <simon.meier@inf.ethz.ch>,
        Jannik Dreier <research@jannikdreier.net>,
        Ralf Sasse <ralf.sasse@gmail.com>
homepage: https://tamarin-prover.github.io/
synopsis: Utility library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
category: Theorem Provers
abi: 1af9cd9737abdc52b8fffb6d2b19d4cb
exposed: True
exposed-modules:
    Control.Basics Control.Monad.Bind Control.Monad.Disj
    Control.Monad.Fresh Control.Monad.Trans.FastFresh
    Control.Monad.Trans.PreciseFresh Data.Color Data.DAG.Simple
    Debug.Trace.Ignore Extension.Data.Bounded Extension.Data.ByteString
    Extension.Data.Label Extension.Data.Monoid Extension.Prelude
    Logic.Connectives System.Timing Text.Dot Text.PrettyPrint.Class
    Text.PrettyPrint.Highlight Text.PrettyPrint.Html Text.Unicode
    Utils.Misc
hidden-modules: Control.Monad.Fresh.Class Control.Monad.Trans.Disj
                Control.Monad.Disj.Class
import-dirs: /usr/lib/ghc-8.6.3/site-local/tamarin-prover-utils-1.4.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/tamarin-prover-utils-1.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/tamarin-prover-utils-1.4.0
hs-libraries: HStamarin-prover-utils-1.4.0-7FcHB8rkcz5IDYEgw7ddaE
depends:
    SHA-1.6.4.4-1GMMHy6WdrlGpMrtGTWHUv base-4.12.0.0
    base64-bytestring-1.0.0.2-EczxCDNMKyZ4D2mi23kJIl binary-0.8.6.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    containers-0.6.0.1 deepseq-1.4.4.0
    dlist-0.8.0.5-HU8Aimky3DbFEV0DkwGifS
    fclabels-2.0.3.3-BnphqeNcghO5EF7ELGWEgj mtl-2.2.2 pretty-1.1.3.6
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji syb-0.7-KRW1LCxdMiCJrmhxCvzo37
    time-1.8.0.2 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-tamarin-prover-utils/html/tamarin-prover-utils.haddock
haddock-html: /usr/share/doc/haskell-tamarin-prover-utils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
